﻿using System;
using System.Data;
using System.Web.UI;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.WebEdition;
using System.Web.UI.WebControls;

public partial class _Default : System.Web.UI.Page
{
    private DataTable dataSource;

    protected void Page_Load(object sender, EventArgs e)
    {
        if (!Page.IsPostBack)
        {
            Map1.MapBackground.BackgroundBrush = new GeoSolidBrush(GeoColor.FromHtml("#B3C6D4"));
            Map1.CurrentExtent = new RectangleShape(-131.22, 55.05, -54.03, 16.91);
            Map1.MapUnit = GeographyUnit.DecimalDegree;

            ShapeFileFeatureLayer statesLayer = new ShapeFileFeatureLayer(MapPath("~/app_data/states.shp"));
            statesLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.CreateSimpleAreaStyle(GeoColor.FromArgb(255, 243, 239, 228), GeoColor.FromArgb(255, 218, 193, 163), 1);
            statesLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            LayerOverlay statesOverlay = new LayerOverlay("StatesOverlay", true, TileType.MultipleTile);
            statesOverlay.Layers.Add(statesLayer);
            Map1.CustomOverlays.Add(statesOverlay);

            InMemoryFeatureLayer routeLayer = new InMemoryFeatureLayer();
            routeLayer.ZoomLevelSet.ZoomLevel01.DefaultLineStyle = LineStyles.CreateSimpleLineStyle(GeoColor.StandardColors.OliveDrab, 3, true);
            routeLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            LayerOverlay routeOverlay = new LayerOverlay("Route", false, TileType.SingleTile);
            routeOverlay.Layers.Add(routeLayer);

            SetDataSource();

            SimpleMarkerOverlay markerOverlay = new SimpleMarkerOverlay("MarkerOverlay");

            LineShape lineShape = new LineShape();
            foreach (DataRow dr in dataSource.Rows)
            {
                string id = (string)dr["id"];
                double x = (double)dr["x"];
                double y = (double)dr["y"];
                markerOverlay.Markers.Add(GetMarker(id, x, y));
                lineShape.Vertices.Add(new Vertex(x, y));
            }
            routeLayer.InternalFeatures.Add(new Feature(lineShape));

            Map1.CustomOverlays.Add(routeOverlay);
            Map1.CustomOverlays.Add(markerOverlay);
            Repeater1.DataSource = dataSource;
            Repeater1.DataBind();
        }
    }

    protected void CheckBoxChanged(object sender, EventArgs e)
    {
        CheckBox cbx = (CheckBox)sender;
        string id = cbx.Text;

        SimpleMarkerOverlay markerOverlay = (SimpleMarkerOverlay)Map1.CustomOverlays["MarkerOverlay"];

        if (cbx.Checked)
        {
            DataTable dt = (DataTable)ViewState["DataSource"];
            int rowIndex = Int32.Parse(cbx.Attributes["RowIndex"]);
            DataRow dr = dt.Rows[rowIndex];
            double x = (double)dr["x"];
            double y = (double)dr["y"];
            markerOverlay.Markers.Add(GetMarker(id, x, y));
        }
        else
        {
            markerOverlay.Markers.Remove(id);
        }
    }

    protected void CheckBoxAllChanged(object sender, EventArgs e)
    {
        CheckBox cbx = (CheckBox)sender;
        string id = cbx.Text;

        SimpleMarkerOverlay markerOverlay = (SimpleMarkerOverlay)Map1.CustomOverlays["MarkerOverlay"];
        markerOverlay.IsVisible = cbx.Checked;
    }

    protected void CheckBoxRouteChanged(object sender, EventArgs e)
    {
        CheckBox cbx = (CheckBox)sender;
        LayerOverlay routeOverlay = (LayerOverlay)Map1.CustomOverlays["Route"];
        routeOverlay.IsVisible = cbx.Checked;
    }

    protected void Repeater1_ItemDataBound(object sender, RepeaterItemEventArgs e)
    {
        CheckBox cbx = (CheckBox)e.Item.FindControl("CheckBox");
        cbx.Attributes.Add("RowIndex", e.Item.ItemIndex.ToString());
    }

    private Marker GetMarker(string id, double x, double y)
    {
        Marker marker = new Marker(x, y);
        marker.Id = id;
        marker.WebImage.ImageVirtualPath = "marker_blue.gif";
        marker.WebImage.ImageWidth = 21;
        marker.WebImage.ImageHeight = 25;
        marker.WebImage.ImageOffsetX = -10.5f;
        marker.WebImage.ImageOffsetY = -25f;
        marker.Popup.ContentHtml = String.Format("Aircraft {0}", id);
        marker.Popup.AutoSize = true;
        return marker;
    }

    private void SetDataSource()
    {
        dataSource = new DataTable();
        dataSource.Columns.Add("id", typeof(string));
        dataSource.Columns.Add("x", typeof(double));
        dataSource.Columns.Add("y", typeof(double));

        dataSource.Rows.Add(NewDataRow("1", -60, 35));
        dataSource.Rows.Add(NewDataRow("2", -70, 40));
        dataSource.Rows.Add(NewDataRow("3", -80, 45));
        dataSource.Rows.Add(NewDataRow("4", -90, 50));
        dataSource.Rows.Add(NewDataRow("5", -100, 45));
        dataSource.Rows.Add(NewDataRow("6", -110, 40));
        dataSource.Rows.Add(NewDataRow("7", -120, 35));

        ViewState["DataSource"] = dataSource;
    }

    private DataRow NewDataRow(string id, double x, double y)
    {
        DataRow dr = dataSource.NewRow();
        dr["id"] = "Aircraft " + id;
        dr["x"] = x;
        dr["y"] = y;

        return dr;
    }
}
